# Files for tailwindcss

`styles.css` and `tailwind.config.js` are automatically generated by the `tailwind_config` django
management command. The source for these files are in `src/argus_htmx/templates/tailwind/`

The `snippets` contains additional css snippets that are included in the final `styles.css`
